/*
 * File:                EstimableDistribution.java
 * Authors:             Kevin R. Dixon
 * Company:             Sandia National Laboratories
 * Project:             Cognitive Foundry
 * 
 * Copyright Jul 14, 2010, Sandia Corporation.
 * Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
 * license for use of this work by or on behalf of the U.S. Government.
 * Export of this program may require a license from the United States
 * Government. See CopyrightHistory.txt for complete details.
 * 
 */

package gov.sandia.cognition.statistics;

/**
 * A Distribution that has an estimator associated with it, typically a
 * closed-form estimator.
 * @param <ObservationType>
 * Type of observations generated by the Distribution.
 * @param <DistributionType>
 * Type of distribution returned from the DistributionEstimator.
 * @author Kevin R. Dixon
 * @since 3.1
 */
public interface EstimableDistribution<ObservationType,DistributionType extends EstimableDistribution<ObservationType,? extends DistributionType>>
    extends Distribution<ObservationType>
{

    /**
     * Gets an estimator associated with this distribution.
     * 
     * @return
     *      A distribution estimator associated for this distribution.
     */
    public DistributionEstimator<ObservationType,? extends DistributionType> getEstimator();

    
}
