/*
 * File:                ConfidenceStatistic.java
 * Authors:             Kevin R. Dixon
 * Company:             Sandia National Laboratories
 * Project:             Cognitive Foundry
 *
 * Copyright August 16, 2007, Sandia Corporation.  Under the terms of Contract
 * DE-AC04-94AL85000, there is a non-exclusive license for use of this work by
 * or on behalf of the U.S. Government. Export of this program may require a
 * license from the United States Government. See CopyrightHistory.txt for
 * complete details.
 *
 */

package gov.sandia.cognition.statistics.method;

import gov.sandia.cognition.util.CloneableSerializable;

/**
 * An interface that describes the result of a statistical confidence test.
 *
 * @author Kevin R. Dixon
 * @since  2.0
 *
 */
public interface ConfidenceStatistic
    extends CloneableSerializable
{
    
    /**
     * Gets the probability that the null hypothesis is correct.  That is,
     * the probability that two datasets were generated by the same
     * distribution.  Generally, social scientists try to demonstrate that
     * NullHypothesisProbability less than 0.05 to show that distributions are
     * different. This is often called the "p-value" of a significance test.
     * @return
     * Probability of the null hypothesis, often called "p-value"
     */
    public double getNullHypothesisProbability();
    
    /**
     * Gets the statistic from which we compute the null-hypothesis probability.
     * In an ANOVA, this would be the "F" statistic.  In a t-test, this would
     * be the "t" value.  And so forth.
     * @return
     * Confidence statistic used to compute the null-hypothesis probability.
     */
    public double getTestStatistic();

}
